@@ -1,9 +1,7 @@
 from json import loads
-import os
-import sys
+from os import path
+from sys import argv
 
-print(os.path.dirname(os.path.realpath(__file__)))
-print(sys.path[0])
 print(os.path.dirname(os.path.realpath(sys.argv[0])))
 
 def nori(args):
